Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(692)

Unified Diff: logdog/api/config/svcconfig/util.go

Issue 2644853005: Update project/service config references. (Closed)
Patch Set: Update project/service config references. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « common/runtime/profiling/profiler.go ('k') | logdog/api/config/svcconfig/validate/main.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: logdog/api/config/svcconfig/util.go
diff --git a/logdog/api/config/svcconfig/util.go b/logdog/api/config/svcconfig/util.go
index 126dc8d0a7b82c757902e16ec79f5194b05bb2c0..f40b388d8392da09bf1c4668d1dff5b79e8a3edd 100644
--- a/logdog/api/config/svcconfig/util.go
+++ b/logdog/api/config/svcconfig/util.go
@@ -4,7 +4,15 @@
package svcconfig
+import (
+ "fmt"
+)
+
const (
- // ServiceConfigFilename is the config service path of the Config protobuf.
- ServiceConfigFilename = "services.cfg"
+ // ServiceConfigPath is the config service path of the Config protobuf.
+ ServiceConfigPath = "services.cfg"
)
+
+// ProjectConfigPath returns the path of a LogDog project config given the
+// LogDog service's name.
+func ProjectConfigPath(serviceName string) string { return fmt.Sprintf("%s.cfg", serviceName) }
« no previous file with comments | « common/runtime/profiling/profiler.go ('k') | logdog/api/config/svcconfig/validate/main.go » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698